.. -*- coding: utf-8 -*-

What's next?
------------

We demonstrated how from a straight out of the box *CubicWeb* installation, you
can build your web application based on a data model. It's all already there:
views, templates, permissions, etc. The step forward is now for you to customize
according to your needs.

Many features are available to extend your application, for example: RSS channel
integration (:ref:`XmlAndRss`), hooks (:ref:`hooks`), support of sources such as
Google App Engine (:ref:`GoogleAppEngineSource`) and lots of others to discover
through our book.

